Crate witnet_bls_signatures

Crate witnet_bls_signatures 

This crate provides:

  • MultiSignature trait for specifying curves with multi signature support.
  • bn256 module implementing the aforementioned trait for the BLS curve bn256.

Modules

bn256
BLS aggregate signatures with bn256.

Traits

MultiSignature
The MultiSignature trait specifies an interface common for curves with multi signature support.